# Fastapi Mongo 

## Contributing
Contributions are welcome! See CONTRIBUTING.md for more details on how to get involved.

## License
Distributed under the MIT License. See LICENSE for more information.
